# Generated by Django 5.0.1 on 2024-02-07 22:53

import django.core.validators
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_action_item",
            "0036_alter_actionitem_priority_alter_actionitem_site_and_more",
        ),
        ("edc_lab", "0034_alter_aliquot_site_alter_box_site_and_more"),
        ("edc_mnsi", "0008_alter_historicalmnsi_site_alter_mnsi_site"),
        (
            "edc_pharmacy",
            "0022_alter_historicalproduct_site_alter_historicalrx_site_and_more",
        ),
        (
            "meta_lists",
            "0016_alter_abnormalfootappearanceobservations_options_and_more",
        ),
        ("meta_prn", "0055_alter_endofstudy_site_and_more"),
        (
            "meta_subject",
            "0162_alter_followupexamination_abdominal_tenderness_and_more",
        ),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="birthoutcomes",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Birth Outcomes",
                "verbose_name_plural": "Birth Outcomes",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsfbc",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: FBC",
                "verbose_name_plural": "Blood Results: FBC",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsglu",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: Glucose",
                "verbose_name_plural": "Blood Results: Glucose",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultshba1c",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: HbA1c",
                "verbose_name_plural": "Blood Results: HbA1c",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsins",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: Insulin",
                "verbose_name_plural": "Blood Results: Insulin",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultslft",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: LFT",
                "verbose_name_plural": "Blood Results: LFT",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultslipid",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: Lipids",
                "verbose_name_plural": "Blood Results: Lipids",
            },
        ),
        migrations.AlterModelOptions(
            name="bloodresultsrft",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Blood Result: RFT",
                "verbose_name_plural": "Blood Results: RFT",
            },
        ),
        migrations.AlterModelOptions(
            name="complications",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Presence of Complications",
                "verbose_name_plural": "Presence of Complications",
            },
        ),
        migrations.AlterModelOptions(
            name="complicationsglycemia",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Complications (Raised Glycemia)",
                "verbose_name_plural": "Complications (Raised Glycemia)",
            },
        ),
        migrations.AlterModelOptions(
            name="concomitantmedication",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Concomitant Medication",
                "verbose_name_plural": "Concomitant Medication",
            },
        ),
        migrations.AlterModelOptions(
            name="delivery",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Delivery",
                "verbose_name_plural": "Delivery",
            },
        ),
        migrations.AlterModelOptions(
            name="dietandlifestyle",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinic follow up: Examination",
                "verbose_name_plural": "Clinic follow up: Examination",
            },
        ),
        migrations.AlterModelOptions(
            name="egfrdropnotification",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "eGFR Drop Notification",
                "verbose_name_plural": "eGFR Drop Notifications",
            },
        ),
        migrations.AlterModelOptions(
            name="eq5d3l",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "EuroQol EQ-5D-3L Instrument",
                "verbose_name_plural": "EuroQol EQ-5D-3L Instrument",
            },
        ),
        migrations.AlterModelOptions(
            name="followupexamination",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinic follow up: Examination",
                "verbose_name_plural": "Clinic follow up: Examination",
            },
        ),
        migrations.AlterModelOptions(
            name="followupvitals",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Clinic follow up: Vitals",
                "verbose_name_plural": "Clinic follow ups: Vitals",
            },
        ),
        migrations.AlterModelOptions(
            name="glucose",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Glucose (IFG, OGTT)",
                "verbose_name_plural": "Glucose (IFG, OGTT)",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomics",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Economics (M2)",
                "verbose_name_plural": "Health Economics (M2)",
            },
        ),
        migrations.AlterModelOptions(
            name="healtheconomicssimple",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Economics (M3)",
                "verbose_name_plural": "Health Economics (M3)",
            },
        ),
        migrations.AlterModelOptions(
            name="hepatitistest",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Hepatitis Tests",
                "verbose_name_plural": "Hepatitis Tests",
            },
        ),
        migrations.AlterModelOptions(
            name="malariatest",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Malaria Test",
            },
        ),
        migrations.AlterModelOptions(
            name="medicationadherence",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Medication Adherence",
                "verbose_name_plural": "Medication Adherence",
            },
        ),
        migrations.AlterModelOptions(
            name="mnsi",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Michigan Neuropathy Screening Instrument (MNSI)",
                "verbose_name_plural": "Michigan Neuropathy Screening Instrument (MNSI)",
            },
        ),
        migrations.AlterModelOptions(
            name="otherarvregimens",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Other ARV Regimens",
                "verbose_name_plural": "Other ARV Regimens",
            },
        ),
        migrations.AlterModelOptions(
            name="otherarvregimensdetail",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Other ARV Regimens Detail",
                "verbose_name_plural": "Other ARV Regimens Detail",
            },
        ),
        migrations.AlterModelOptions(
            name="patienthistory",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Patient History",
                "verbose_name_plural": "Patient History",
            },
        ),
        migrations.AlterModelOptions(
            name="physicalexam",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Physical Exam",
                "verbose_name_plural": "Physical Exams",
            },
        ),
        migrations.AlterModelOptions(
            name="pregnancyupdate",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Pregnancy Update",
                "verbose_name_plural": "Pregnancy Update",
            },
        ),
        migrations.AlterModelOptions(
            name="sf12",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "SF-12 Health Survey",
                "verbose_name_plural": "SF-12 Health Survey",
            },
        ),
        migrations.AlterModelOptions(
            name="studymedication",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Study Medication",
                "verbose_name_plural": "Study Medication",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectrequisition",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisit",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.AlterModelOptions(
            name="subjectvisitmissed",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Missed Visit Report",
                "verbose_name_plural": "Missed Visit Report",
            },
        ),
        migrations.AlterModelOptions(
            name="urinedipsticktest",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Urine Dipstick Test",
            },
        ),
        migrations.AlterModelOptions(
            name="urinepregnancy",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Urine Pregnancy",
            },
        ),
        migrations.RemoveIndex(
            model_name="bloodresultsfbc",
            name="meta_subjec_subject_1371de_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultsglu",
            name="meta_subjec_subject_b01b25_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultshba1c",
            name="meta_subjec_subject_e39ef5_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultsins",
            name="meta_subjec_subject_b1df05_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultslft",
            name="meta_subjec_subject_63bf05_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultslipid",
            name="meta_subjec_subject_c41a0b_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultsrft",
            name="meta_subjec_subject_f9cf1d_idx",
        ),
        migrations.RemoveIndex(
            model_name="complications",
            name="meta_subjec_subject_7ee33b_idx",
        ),
        migrations.RemoveIndex(
            model_name="complicationsglycemia",
            name="meta_subjec_subject_3c1655_idx",
        ),
        migrations.RemoveIndex(
            model_name="concomitantmedication",
            name="meta_subjec_subject_7479b1_idx",
        ),
        migrations.RemoveIndex(
            model_name="delivery",
            name="meta_subjec_subject_e0559c_idx",
        ),
        migrations.RemoveIndex(
            model_name="dietandlifestyle",
            name="meta_subjec_subject_0c33b8_idx",
        ),
        migrations.RemoveIndex(
            model_name="egfrdropnotification",
            name="meta_subjec_subject_e1dd63_idx",
        ),
        migrations.RemoveIndex(
            model_name="eq5d3l",
            name="meta_subjec_subject_554b24_idx",
        ),
        migrations.RemoveIndex(
            model_name="followupexamination",
            name="meta_subjec_subject_aad749_idx",
        ),
        migrations.RemoveIndex(
            model_name="followupvitals",
            name="meta_subjec_subject_832c2d_idx",
        ),
        migrations.RemoveIndex(
            model_name="glucose",
            name="meta_subjec_subject_35e440_idx",
        ),
        migrations.RemoveIndex(
            model_name="healtheconomics",
            name="meta_subjec_subject_98fe4f_idx",
        ),
        migrations.RemoveIndex(
            model_name="healtheconomicssimple",
            name="meta_subjec_subject_a13289_idx",
        ),
        migrations.RemoveIndex(
            model_name="hepatitistest",
            name="meta_subjec_subject_424a4b_idx",
        ),
        migrations.RemoveIndex(
            model_name="malariatest",
            name="meta_subjec_subject_038dbe_idx",
        ),
        migrations.RemoveIndex(
            model_name="medicationadherence",
            name="meta_subjec_subject_a06028_idx",
        ),
        migrations.RemoveIndex(
            model_name="mnsi",
            name="meta_subjec_subject_0deea5_idx",
        ),
        migrations.RemoveIndex(
            model_name="otherarvregimens",
            name="meta_subjec_subject_323829_idx",
        ),
        migrations.RemoveIndex(
            model_name="patienthistory",
            name="meta_subjec_subject_ceac36_idx",
        ),
        migrations.RemoveIndex(
            model_name="physicalexam",
            name="meta_subjec_subject_7da1da_idx",
        ),
        migrations.RemoveIndex(
            model_name="pregnancyupdate",
            name="meta_subjec_subject_4cce95_idx",
        ),
        migrations.RemoveIndex(
            model_name="sf12",
            name="meta_subjec_subject_6b795b_idx",
        ),
        migrations.RemoveIndex(
            model_name="studymedication",
            name="meta_subjec_subject_4198c4_idx",
        ),
        migrations.RemoveIndex(
            model_name="subjectrequisition",
            name="meta_subjec_subject_2bb98e_idx",
        ),
        migrations.RemoveIndex(
            model_name="subjectvisitmissed",
            name="meta_subjec_subject_89b092_idx",
        ),
        migrations.RemoveIndex(
            model_name="urinedipsticktest",
            name="meta_subjec_subject_7cf807_idx",
        ),
        migrations.RemoveIndex(
            model_name="urinepregnancy",
            name="meta_subjec_subject_11189d_idx",
        ),
        migrations.AlterUniqueTogether(
            name="subjectrequisition",
            unique_together=set(),
        ),
        migrations.AddField(
            model_name="birthoutcomes",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="birthoutcomes",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsglu",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsglu",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultshba1c",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultshba1c",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsins",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsins",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="complications",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="complications",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="complicationsglycemia",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="complicationsglycemia",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="concomitantmedication",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="concomitantmedication",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="delivery",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="delivery",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="dietandlifestyle",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="dietandlifestyle",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="egfrdropnotification",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="egfrdropnotification",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="eq5d3l",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="eq5d3l",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="followupexamination",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="followupexamination",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="followupvitals",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="followupvitals",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="glucose",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="glucose",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomics",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomics",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicssimple",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicssimple",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="hepatitistest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="hepatitistest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbirthoutcomes",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbirthoutcomes",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsglu",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsglu",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultshba1c",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultshba1c",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsins",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsins",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalcomplications",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalcomplications",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalcomplicationsglycemia",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalcomplicationsglycemia",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalconcomitantmedication",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalconcomitantmedication",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicaldelivery",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicaldelivery",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicaldietandlifestyle",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicaldietandlifestyle",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalegfrdropnotification",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalegfrdropnotification",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicaleq5d3l",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicaleq5d3l",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupexamination",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupexamination",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupvitals",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupvitals",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomics",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomics",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicssimple",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicssimple",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalhepatitistest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalhepatitistest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalmalariatest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalmalariatest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalmedicationadherence",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalmedicationadherence",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalmnsi",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalmnsi",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalotherarvregimens",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalotherarvregimens",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalotherarvregimensdetail",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalotherarvregimensdetail",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatienthistory",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatienthistory",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalphysicalexam",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalphysicalexam",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalpregnancyupdate",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalpregnancyupdate",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsf12",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsf12",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalstudymedication",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalstudymedication",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectrequisition",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectrequisition",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisit",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisit",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalurinedipsticktest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalurinedipsticktest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalurinepregnancy",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalurinepregnancy",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="malariatest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="malariatest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="medicationadherence",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="medicationadherence",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="mnsi",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="mnsi",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="otherarvregimens",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="otherarvregimens",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="otherarvregimensdetail",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="otherarvregimensdetail",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="patienthistory",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="patienthistory",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="physicalexam",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="physicalexam",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="pregnancyupdate",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="pregnancyupdate",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="sf12",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="sf12",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="studymedication",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="studymedication",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjectrequisition",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjectrequisition",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisit",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisit",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="urinedipsticktest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="urinedipsticktest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="urinepregnancy",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="urinepregnancy",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="birthoutcomes",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="platelets_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="Platelets",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="ast_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="AST",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="ggt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="GGT",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="complications",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="complicationsglycemia",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="concomitantmedication",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="delivery",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="dietandlifestyle",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="egfrdropnotification",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="eq5d3l",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="followupvitals",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicssimple",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="hepatitistest",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbirthoutcomes",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="platelets_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="Platelets",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="ast_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="AST",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="ggt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="GGT",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplications",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcomplicationsglycemia",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalconcomitantmedication",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldelivery",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldietandlifestyle",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalegfrdropnotification",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicaleq5d3l",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicssimple",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhepatitistest",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmalariatest",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="pregnancyupdate",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="sf12",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrequisition",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="urinedipsticktest",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="urinepregnancy",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AddIndex(
            model_name="birthoutcomes",
            index=models.Index(
                fields=["delivery", "birth_order"],
                name="meta_subjec_deliver_b18ef1_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="bloodresultsfbc",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_9226cd_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="bloodresultsglu",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_199c7b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="bloodresultshba1c",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_aa5502_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="bloodresultsins",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_1f0998_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="bloodresultslft",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_cf22bb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="bloodresultslipid",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_296de9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="bloodresultsrft",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_371dcd_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="complications",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_eaa718_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="complicationsglycemia",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_a5f193_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="concomitantmedication",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_dd0003_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="delivery",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_0f743d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dietandlifestyle",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_a88c62_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="egfrdropnotification",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_08cc05_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="eq5d3l",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_7f71d4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="followupexamination",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_9f040f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="followupvitals",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_e4c06a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="glucose",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_72ef04_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomics",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_64cf7e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicssimple",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_898e39_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hepatitistest",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_865f11_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="malariatest",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_813df8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="medicationadherence",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_0aa3c7_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="mnsi",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_3b99d3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherarvregimens",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_7fb313_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherarvregimensdetail",
            index=models.Index(
                fields=["modified", "created"], name="meta_subjec_modifie_c6997a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherarvregimensdetail",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="meta_subjec_user_mo_26f231_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="patienthistory",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_647a94_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="physicalexam",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_32ea3f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="pregnancyupdate",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_8359df_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="sf12",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_bf8740_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="studymedication",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_d453e7_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_identifier"], name="meta_subjec_subject_5e52da_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_visit", "site", "panel"],
                name="meta_subjec_subject_2a398c_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_visit", "panel"], name="meta_subjec_subject_615fc0_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissed",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_5e736b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="urinedipsticktest",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_6e63fa_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="urinepregnancy",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_749d86_idx"
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectrequisition",
            constraint=models.UniqueConstraint(
                fields=("panel", "subject_visit"),
                name="meta_subject_subjectrequisition_panel_uniq",
            ),
        ),
    ]



# Generated by Django 5.2.6 on 2025-09-30 00:41

import _socket
import django.db.models.deletion
import django.utils.timezone
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.validators.date
import edc_protocol.validators
import edc_visit_tracking.managers
import simple_history.models
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0232_alter_patienthistory_concomitant_conditions_and_more"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="HistoricalSpfq",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        default="",
                        editable=False,
                        help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                        max_length=75,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "modified",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        default="",
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        default="",
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        default="",
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(
                        blank=True,
                        default="",
                        max_length=10,
                        verbose_name="Device created",
                    ),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True,
                        default="",
                        max_length=10,
                        verbose_name="Device modified",
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(blank=True, default="", max_length=50),
                ),
                (
                    "consent_version",
                    models.CharField(blank=True, default="", max_length=10),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=django.utils.timezone.now,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        default="",
                        help_text="for example, why some data is still pending",
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "a01",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: when and how to take or use a treatment",
                        max_length=25,
                        verbose_name="I understood the treatment process in this trial",
                    ),
                ),
                (
                    "a02",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: visits and procedures, time commitment, who to contact with questions",
                        max_length=25,
                        verbose_name="The information given to me before I joined the trial was everything I wanted to know",
                    ),
                ),
                (
                    "a03",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: visits and procedures, time commitment, who to contact with questions",
                        max_length=25,
                        verbose_name="The information given to me before I joined the trial was easy for me to understand",
                    ),
                ),
                (
                    "a04",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="I felt comfortable that I could ask any questions before I joined the trial",
                    ),
                ),
                (
                    "b01",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: comfort and privacy of treatment area, waiting area, parking, ease of access to the site",
                        max_length=25,
                        verbose_name="Overall I was satisfied with the trial site",
                    ),
                ),
                (
                    "b02",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="My trial visits were well organized",
                    ),
                ),
                (
                    "b03",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="My trial visits were scheduled at a convenient time for me",
                    ),
                ),
                (
                    "b04",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="The staff treated me with respect",
                    ),
                ),
                (
                    "b05",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="I felt comfortable that I could ask questions during the trial",
                    ),
                ),
                (
                    "b06",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="I was satisfied with the answers I have received to my questions during the trial",
                    ),
                ),
                (
                    "b07",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="for example: in person visits, questionnaires, forms",
                        max_length=25,
                        verbose_name="The time taken to collect data was acceptable to me",
                    ),
                ),
                (
                    "b08",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="for example: household chores, work commitments, eating",
                        max_length=25,
                        verbose_name="The impact the trial has had on my daily activities is acceptable",
                    ),
                ),
                (
                    "b09",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="for example: in person, online questionnaire, diary, wearable sensors, monitoring machines, technology",
                        max_length=25,
                        verbose_name="The way in which trial data is being collected is acceptable to me",
                    ),
                ),
                (
                    "b10",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: blood tests, scans etc.",
                        max_length=25,
                        verbose_name="Optional: I am being kept informed of the results of my medical tests done during the trial, including during screening",
                    ),
                ),
                (
                    "c01",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="I was informed when I had completed the trial",
                    ),
                ),
                (
                    "c02",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="I was informed of any future opportunities to access the overall trial results if I wanted to",
                    ),
                ),
                (
                    "c03",
                    models.CharField(
                        choices=[
                            ("very_difficult", "Very difficult"),
                            ("difficult", "Difficult"),
                            ("neutral", "Neutral"),
                            ("easy", "Easy"),
                            ("very_easy", "Very easy"),
                        ],
                        max_length=25,
                        verbose_name="How easy was it to take the medication?",
                    ),
                ),
                (
                    "c04",
                    models.CharField(
                        choices=[
                            ("not_at_all", "Not at all"),
                            ("slight", "Slight"),
                            ("moderate", "Moderate"),
                            ("extreme", "Extreme"),
                            ("severe", "Severe"),
                        ],
                        max_length=25,
                        verbose_name="Did you experience any burden or side effects?",
                    ),
                ),
                (
                    "c05",
                    models.CharField(
                        choices=[
                            ("not_at_all", "Not at all"),
                            ("slightly", "Slightly"),
                            ("moderately", "Moderately"),
                            ("highly", "Highly"),
                            ("very_highly", "Very highly"),
                        ],
                        max_length=25,
                        verbose_name="How acceptable was it to take the drug?",
                    ),
                ),
                (
                    "c06",
                    models.CharField(
                        choices=[
                            ("very_difficult", "Very difficult"),
                            ("difficult", "Difficult"),
                            ("neutral", "Neutral"),
                            ("easy", "Easy"),
                            ("very_easy", "Very easy"),
                        ],
                        max_length=25,
                        verbose_name="How easy was it to fit the medication into your routine?",
                    ),
                ),
                (
                    "c07",
                    models.CharField(
                        choices=[
                            ("not_at_all", "Not at all"),
                            ("slight", "Slight"),
                            ("moderate", "Moderate"),
                            ("extreme", "Extreme"),
                            ("severe", "Severe"),
                        ],
                        max_length=25,
                        verbose_name="How burdensome was taking part in the trial?",
                    ),
                ),
                (
                    "c08",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: future treatment, follow-up contact details",
                        max_length=25,
                        verbose_name="Overall, I was satisfied with the information I received about future support after the trial",
                    ),
                ),
                (
                    "c09",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="Overall, I was satisfied with my trial experience",
                    ),
                ),
                (
                    "c10",
                    models.CharField(
                        choices=[
                            ("much_less_expected", "Much less than expected"),
                            ("somewhat_less_expected", "Somewhat less than expected"),
                            ("same_as_expected", "Same as expected"),
                            ("somewhat_more_expected", "Somewhat more than expected"),
                            ("much_more_expected", "Much more than expected"),
                        ],
                        max_length=25,
                        verbose_name="Compared to when the trial started, the overall commitment required was similar to what I expected",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Feedback Questionnaire (SPFQ)",
                "verbose_name_plural": "historical Feedback Questionnaires (SPFQ)",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="Spfq",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        default="",
                        editable=False,
                        help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                        max_length=75,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "modified",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        default="",
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        default="",
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        default="",
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(
                        blank=True,
                        default="",
                        max_length=10,
                        verbose_name="Device created",
                    ),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True,
                        default="",
                        max_length=10,
                        verbose_name="Device modified",
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(blank=True, default="", max_length=50),
                ),
                (
                    "consent_version",
                    models.CharField(blank=True, default="", max_length=10),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=django.utils.timezone.now,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        default="",
                        help_text="for example, why some data is still pending",
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "a01",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: when and how to take or use a treatment",
                        max_length=25,
                        verbose_name="I understood the treatment process in this trial",
                    ),
                ),
                (
                    "a02",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: visits and procedures, time commitment, who to contact with questions",
                        max_length=25,
                        verbose_name="The information given to me before I joined the trial was everything I wanted to know",
                    ),
                ),
                (
                    "a03",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: visits and procedures, time commitment, who to contact with questions",
                        max_length=25,
                        verbose_name="The information given to me before I joined the trial was easy for me to understand",
                    ),
                ),
                (
                    "a04",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="I felt comfortable that I could ask any questions before I joined the trial",
                    ),
                ),
                (
                    "b01",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: comfort and privacy of treatment area, waiting area, parking, ease of access to the site",
                        max_length=25,
                        verbose_name="Overall I was satisfied with the trial site",
                    ),
                ),
                (
                    "b02",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="My trial visits were well organized",
                    ),
                ),
                (
                    "b03",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="My trial visits were scheduled at a convenient time for me",
                    ),
                ),
                (
                    "b04",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="The staff treated me with respect",
                    ),
                ),
                (
                    "b05",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="I felt comfortable that I could ask questions during the trial",
                    ),
                ),
                (
                    "b06",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="I was satisfied with the answers I have received to my questions during the trial",
                    ),
                ),
                (
                    "b07",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="for example: in person visits, questionnaires, forms",
                        max_length=25,
                        verbose_name="The time taken to collect data was acceptable to me",
                    ),
                ),
                (
                    "b08",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="for example: household chores, work commitments, eating",
                        max_length=25,
                        verbose_name="The impact the trial has had on my daily activities is acceptable",
                    ),
                ),
                (
                    "b09",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="for example: in person, online questionnaire, diary, wearable sensors, monitoring machines, technology",
                        max_length=25,
                        verbose_name="The way in which trial data is being collected is acceptable to me",
                    ),
                ),
                (
                    "b10",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: blood tests, scans etc.",
                        max_length=25,
                        verbose_name="Optional: I am being kept informed of the results of my medical tests done during the trial, including during screening",
                    ),
                ),
                (
                    "c01",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="I was informed when I had completed the trial",
                    ),
                ),
                (
                    "c02",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="I was informed of any future opportunities to access the overall trial results if I wanted to",
                    ),
                ),
                (
                    "c03",
                    models.CharField(
                        choices=[
                            ("very_difficult", "Very difficult"),
                            ("difficult", "Difficult"),
                            ("neutral", "Neutral"),
                            ("easy", "Easy"),
                            ("very_easy", "Very easy"),
                        ],
                        max_length=25,
                        verbose_name="How easy was it to take the medication?",
                    ),
                ),
                (
                    "c04",
                    models.CharField(
                        choices=[
                            ("not_at_all", "Not at all"),
                            ("slight", "Slight"),
                            ("moderate", "Moderate"),
                            ("extreme", "Extreme"),
                            ("severe", "Severe"),
                        ],
                        max_length=25,
                        verbose_name="Did you experience any burden or side effects?",
                    ),
                ),
                (
                    "c05",
                    models.CharField(
                        choices=[
                            ("not_at_all", "Not at all"),
                            ("slightly", "Slightly"),
                            ("moderately", "Moderately"),
                            ("highly", "Highly"),
                            ("very_highly", "Very highly"),
                        ],
                        max_length=25,
                        verbose_name="How acceptable was it to take the drug?",
                    ),
                ),
                (
                    "c06",
                    models.CharField(
                        choices=[
                            ("very_difficult", "Very difficult"),
                            ("difficult", "Difficult"),
                            ("neutral", "Neutral"),
                            ("easy", "Easy"),
                            ("very_easy", "Very easy"),
                        ],
                        max_length=25,
                        verbose_name="How easy was it to fit the medication into your routine?",
                    ),
                ),
                (
                    "c07",
                    models.CharField(
                        choices=[
                            ("not_at_all", "Not at all"),
                            ("slight", "Slight"),
                            ("moderate", "Moderate"),
                            ("extreme", "Extreme"),
                            ("severe", "Severe"),
                        ],
                        max_length=25,
                        verbose_name="How burdensome was taking part in the trial?",
                    ),
                ),
                (
                    "c08",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        help_text="for example: future treatment, follow-up contact details",
                        max_length=25,
                        verbose_name="Overall, I was satisfied with the information I received about future support after the trial",
                    ),
                ),
                (
                    "c09",
                    models.CharField(
                        choices=[
                            ("strongly_disagree", "Strongly disagree"),
                            ("disagree", "disagree"),
                            ("neutral", "Neutral"),
                            ("agree", "Agree"),
                            ("strongly_agree", "Strongly agree"),
                        ],
                        max_length=25,
                        verbose_name="Overall, I was satisfied with my trial experience",
                    ),
                ),
                (
                    "c10",
                    models.CharField(
                        choices=[
                            ("much_less_expected", "Much less than expected"),
                            ("somewhat_less_expected", "Somewhat less than expected"),
                            ("same_as_expected", "Same as expected"),
                            ("somewhat_more_expected", "Somewhat more than expected"),
                            ("much_more_expected", "Much more than expected"),
                        ],
                        max_length=25,
                        verbose_name="Compared to when the trial started, the overall commitment required was similar to what I expected",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "Feedback Questionnaire (SPFQ)",
                "verbose_name_plural": "Feedback Questionnaires (SPFQ)",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "default_manager_name": "objects",
                "indexes": [
                    models.Index(
                        fields=["subject_visit", "site"],
                        name="meta_subjec_subject_7ecbde_idx",
                    ),
                    models.Index(
                        fields=["subject_visit", "report_datetime"],
                        name="meta_subjec_subject_f51f0f_idx",
                    ),
                ],
            },
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
            ],
        ),
    ]



from django.contrib import admin
from edc_qareports.modeladmin_mixins import OnStudyMissingValuesModelAdminMixin

from ....admin_site import meta_reports_admin
from ....models import OnStudyMissingValues


@admin.register(OnStudyMissingValues, site=meta_reports_admin)
class OnStudyMissingValuesAdmin(OnStudyMissingValuesModelAdminMixin, admin.ModelAdmin):
    include_note_column: bool = True
    project_reports_admin: str = "meta_reports_admin"
    project_subject_admin: str = "meta_subject_admin"



from django.contrib.sites.models import Site
from django.core.exceptions import ObjectDoesNotExist
from django_pylabels.models import LabelSpecification
from edc_pharmacy.models import (
    Assignment,
    Container,
    ContainerType,
    ContainerUnits,
    Formulation,
    Location,
    Product,
    Supplier,
)
from edc_pylabels.models import LabelConfiguration
from edc_pylabels.site_label_configs import site_label_configs


def update_initial_pharmacy_data():
    update_assignment()
    update_container()
    update_location()
    update_product()
    update_supplier()
    update_labels()


def update_assignment():
    """For a trial with just active and placebo.

    Better to get these labels from edc_randomizer.
    """
    for assignment in ["placebo", "active"]:
        try:
            Assignment.objects.get(name=assignment)
        except ObjectDoesNotExist:
            Assignment.objects.create(name=assignment, display_name=assignment.title())


def update_container():
    """Here we order a number of tablets. The manufacturer sends
    the order in large containers, barrels of about 30K tablets
    per barrel. We repack/decant into bottles of 128 tablets
    """
    tablet_type = ContainerType.objects.get(name="tablet")
    bottle_type = ContainerType.objects.get(name="bottle")
    units = ContainerUnits.objects.get(name="tablet")
    opts = {
        "tablet": dict(
            name="tablet",
            display_name="Tablet",
            container_type=tablet_type,
            units=units,
            qty=1,
            may_order_as=True,
            max_items_per_subject=0,
        ),
        "bottle30k": dict(
            name="bottle30k",
            display_name="Barrel 30K",
            container_type=bottle_type,
            units=units,
            qty=30000,
            may_receive_as=True,
            max_items_per_subject=0,
        ),
        "bottle128": dict(
            name="bottle128",
            display_name="Bottle 128",
            container_type=bottle_type,
            units=units,
            qty=128,
            max_items_per_subject=3,
            may_repack_as=True,
            may_request_as=True,
            may_dispense_as=True,
        ),
    }
    for name, data in opts.items():
        try:
            Container.objects.get(name=name)
        except ObjectDoesNotExist:
            Container.objects.create(**data)


def update_location():
    """Base the locations on the sites in the trial plus
    a "central" pharmacy"""
    for obj in Location.objects.exclude(name="central"):
        obj.site_id = Site.objects.get(name=obj.name).id
        obj.save(update_fields=["site_id"])


def update_product():
    """Define the product, in this case just two; active and placebo.

    Formulation is defined before running this script.

    In this case the formulation is just the study drug/IMP.
    """
    formulation = Formulation.objects.get()
    active = Assignment.objects.get(name="active")
    placebo = Assignment.objects.get(name="placebo")
    try:
        Product.objects.get(formulation=formulation, assignment=active)
    except ObjectDoesNotExist:
        Product(assignment=active, formulation=formulation).save()
    try:
        Product.objects.get(formulation=formulation, assignment=placebo)
    except ObjectDoesNotExist:
        Product(assignment=placebo, formulation=formulation).save()


def update_supplier():
    """In this case MERCK"""
    try:
        Supplier.objects.get(name="merck")
    except ObjectDoesNotExist:
        Supplier(name="merck").save()


def update_labels():
    """The default label spec is a 2 x 6 label sheet

    Add "label congigs" as registered in the "site_label_configs"
    global. In this case there are three labels:
    * a bulk label for the barrels
    * a generic vertical label for decanted stock (bottles of 128)
    * a patient label for allocated stock (bottles of 128)

    The patient label will be placed over the generic vertical label
    once the stock item is allocated to a subject.
    """
    try:
        default = LabelSpecification.objects.get(name="default")
    except ObjectDoesNotExist:
        LabelSpecification().save()
        default = LabelSpecification.objects.get(name="default")

    for name in site_label_configs.registry:
        LabelConfiguration.objects.create(name=name, label_specification=default)
    for label_configuration in LabelConfiguration.objects.filter(name__contains="patient"):
        label_configuration.requires_allocation = True
        label_configuration.save()


__all__ = ["update_initial_pharmacy_data"]



# Generated by Django 5.1.2 on 2025-01-15 13:29

import edc_sites.managers
import edc_visit_schedule.model_mixins.on_schedule_model_mixin
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0059_alter_historicaloffstudymedication_reason_and_more"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="onschedule",
            managers=[
                (
                    "objects",
                    edc_visit_schedule.model_mixins.on_schedule_model_mixin.OnScheduleManager(),
                ),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="onscheduledmreferral",
            managers=[
                (
                    "objects",
                    edc_visit_schedule.model_mixins.on_schedule_model_mixin.OnScheduleManager(),
                ),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="onschedulepostnatal",
            managers=[
                (
                    "objects",
                    edc_visit_schedule.model_mixins.on_schedule_model_mixin.OnScheduleManager(),
                ),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="onschedulepregnancy",
            managers=[
                (
                    "objects",
                    edc_visit_schedule.model_mixins.on_schedule_model_mixin.OnScheduleManager(),
                ),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
    ]
